==> ejc-salary-api-3.0.0-20241224.015106-95-sources.jar: com/ejianc/business/report/vo/SalaryListVWVO.java <==
package com.ejianc.business.report.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 工资汇总表
 * 
 * @author generator
 * 
 */
public class SalaryListVWVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long jspayableDetailId; // 所属明细id
    private Long detailEmployeeId; // 员工主键
    private String detailEmployeeName; // 员工名称
    private String detailEmployeeCode; // 员工编码
    @JsonFormat(pattern = "yyyy-MM",timezone = "GMT+8")
    private Date month; // 月份
    private String idCard; // 证件号码
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private String orgCode; // 单位编码
    private Long sourceId; // 应发上传id
    private Long sourceDetailId; // 应发上传明细id
    private Date period; // 应发工资计算的 月份
    private Long companyId; // 所属公司id
    private String companyName; // 所属公司名称
    private BigDecimal yingfa; // 
    private BigDecimal dabingyibao; // 
    private BigDecimal gerenyanglao; // 
    private BigDecimal gerenyibao; // 
    private BigDecimal gerenshiye; // 
    private BigDecimal gerengongjijin; // 
    private BigDecimal gsyanglao; // 
    private BigDecimal gsyibao; // 
    private BigDecimal gsshiye; // 
    private BigDecimal gsshengyu; // 
    private BigDecimal gsgongshang; // 
    private BigDecimal gsgongjijin; // 
    private BigDecimal geshui; // 
    private BigDecimal yingfamianshui; // 
    private BigDecimal yingfamianshuicw; // 
    private BigDecimal actual; // 
    private BigDecimal alreadyMny; // 已支付金额
    private String bankName; // 开户行
    private String bankAccount; // 银行账户
    private String bankAddress; // 银行地址
    private String acSetCode; // 账套编码
    private String acSet; // 账套名称
    private String code; //
    private BigDecimal sbPaymentBase; // 社保基数
    private BigDecimal gjjPaymentBase; // 公积金基数


    public BigDecimal getSbPaymentBase() {
        return sbPaymentBase;
    }

    public void setSbPaymentBase(BigDecimal sbPaymentBase) {
        this.sbPaymentBase = sbPaymentBase;
    }

    public BigDecimal getGjjPaymentBase() {
        return gjjPaymentBase;
    }

    public void setGjjPaymentBase(BigDecimal gjjPaymentBase) {
        this.gjjPaymentBase = gjjPaymentBase;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }
    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }
    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    public BigDecimal getYingfa() {
        return yingfa;
    }

    public void setYingfa(BigDecimal yingfa) {
        this.yingfa = yingfa;
    }
    public BigDecimal getDabingyibao() {
        return dabingyibao;
    }

    public void setDabingyibao(BigDecimal dabingyibao) {
        this.dabingyibao = dabingyibao;
    }
    public BigDecimal getGerenyanglao() {
        return gerenyanglao;
    }

    public void setGerenyanglao(BigDecimal gerenyanglao) {
        this.gerenyanglao = gerenyanglao;
    }
    public BigDecimal getGerenyibao() {
        return gerenyibao;
    }

    public void setGerenyibao(BigDecimal gerenyibao) {
        this.gerenyibao = gerenyibao;
    }
    public BigDecimal getGerenshiye() {
        return gerenshiye;
    }

    public void setGerenshiye(BigDecimal gerenshiye) {
        this.gerenshiye = gerenshiye;
    }
    public BigDecimal getGerengongjijin() {
        return gerengongjijin;
    }

    public void setGerengongjijin(BigDecimal gerengongjijin) {
        this.gerengongjijin = gerengongjijin;
    }
    public BigDecimal getGsyanglao() {
        return gsyanglao;
    }

    public void setGsyanglao(BigDecimal gsyanglao) {
        this.gsyanglao = gsyanglao;
    }
    public BigDecimal getGsyibao() {
        return gsyibao;
    }

    public void setGsyibao(BigDecimal gsyibao) {
        this.gsyibao = gsyibao;
    }
    public BigDecimal getGsshiye() {
        return gsshiye;
    }

    public void setGsshiye(BigDecimal gsshiye) {
        this.gsshiye = gsshiye;
    }
    public BigDecimal getGsshengyu() {
        return gsshengyu;
    }

    public void setGsshengyu(BigDecimal gsshengyu) {
        this.gsshengyu = gsshengyu;
    }
    public BigDecimal getGsgongshang() {
        return gsgongshang;
    }

    public void setGsgongshang(BigDecimal gsgongshang) {
        this.gsgongshang = gsgongshang;
    }
    public BigDecimal getGsgongjijin() {
        return gsgongjijin;
    }

    public void setGsgongjijin(BigDecimal gsgongjijin) {
        this.gsgongjijin = gsgongjijin;
    }
    public BigDecimal getGeshui() {
        return geshui;
    }

    public void setGeshui(BigDecimal geshui) {
        this.geshui = geshui;
    }
    public BigDecimal getYingfamianshui() {
        return yingfamianshui;
    }

    public void setYingfamianshui(BigDecimal yingfamianshui) {
        this.yingfamianshui = yingfamianshui;
    }
    public BigDecimal getYingfamianshuicw() {
        return yingfamianshuicw;
    }

    public void setYingfamianshuicw(BigDecimal yingfamianshuicw) {
        this.yingfamianshuicw = yingfamianshuicw;
    }
    public BigDecimal getActual() {
        return actual;
    }

    public void setActual(BigDecimal actual) {
        this.actual = actual;
    }
    public BigDecimal getAlreadyMny() {
        return alreadyMny;
    }

    public void setAlreadyMny(BigDecimal alreadyMny) {
        this.alreadyMny = alreadyMny;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }
    public String getAcSetCode() {
        return acSetCode;
    }

    public void setAcSetCode(String acSetCode) {
        this.acSetCode = acSetCode;
    }
    public String getAcSet() {
        return acSet;
    }

    public void setAcSet(String acSet) {
        this.acSet = acSet;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    
}

==> ejc-salary-api-3.0.0-20250116.033910-103-sources.jar: com/ejianc/business/report/vo/SalaryListVWVO.java <==
package com.ejianc.business.report.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 工资汇总表
 * 
 * @author generator
 * 
 */
public class SalaryListVWVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long jspayableDetailId; // 所属明细id
    private Long detailEmployeeId; // 员工主键
    private String detailEmployeeName; // 员工名称
    private String detailEmployeeCode; // 员工编码
    @JsonFormat(pattern = "yyyy-MM",timezone = "GMT+8")
    private Date month; // 月份
    private String idCard; // 证件号码
    private Long orgId; // 单位id
    private String orgName; // 单位名称
    private String orgCode; // 单位编码
    private Long sourceId; // 应发上传id
    private Long sourceDetailId; // 应发上传明细id
    private Date period; // 应发工资计算的 月份
    private Long companyId; // 所属公司id
    private String companyName; // 所属公司名称
    private BigDecimal yingfa; // 
    private BigDecimal dabingyibao; // 
    private BigDecimal gerenyanglao; // 
    private BigDecimal gerenyibao; // 
    private BigDecimal gerenshiye; // 
    private BigDecimal gerengongjijin; // 
    private BigDecimal gsyanglao; // 
    private BigDecimal gsyibao; // 
    private BigDecimal gsshiye; // 
    private BigDecimal gsshengyu; // 
    private BigDecimal gsgongshang; // 
    private BigDecimal gsgongjijin; // 
    private BigDecimal geshui; // 
    private BigDecimal yingfamianshui; // 
    private BigDecimal yingfamianshuicw; // 
    private BigDecimal actual; // 
    private BigDecimal alreadyMny; // 已支付金额
    private String bankName; // 开户行
    private String bankAccount; // 银行账户
    private String bankAddress; // 银行地址
    private String acSetCode; // 账套编码
    private String acSet; // 账套名称
    private String code; //
    private BigDecimal sbPaymentBase; // 社保基数
    private BigDecimal gjjPaymentBase; // 公积金基数
    private String sbjnOrgName; // 社保缴纳单位名称
    private String sbjnOrgCode; // 社保缴纳单位编码
    private Long sbcdCompanyId; // 社保承担公司id
    private String sbcdCompanyCode; // 社保承担公司编号
    private String sbcdCompanyName; // 社保承担公司

    public String getSbjnOrgName() {
        return sbjnOrgName;
    }

    public void setSbjnOrgName(String sbjnOrgName) {
        this.sbjnOrgName = sbjnOrgName;
    }

    public String getSbjnOrgCode() {
        return sbjnOrgCode;
    }

    public void setSbjnOrgCode(String sbjnOrgCode) {
        this.sbjnOrgCode = sbjnOrgCode;
    }

    public Long getSbcdCompanyId() {
        return sbcdCompanyId;
    }

    public void setSbcdCompanyId(Long sbcdCompanyId) {
        this.sbcdCompanyId = sbcdCompanyId;
    }

    public String getSbcdCompanyCode() {
        return sbcdCompanyCode;
    }

    public void setSbcdCompanyCode(String sbcdCompanyCode) {
        this.sbcdCompanyCode = sbcdCompanyCode;
    }

    public String getSbcdCompanyName() {
        return sbcdCompanyName;
    }

    public void setSbcdCompanyName(String sbcdCompanyName) {
        this.sbcdCompanyName = sbcdCompanyName;
    }

    public BigDecimal getSbPaymentBase() {
        return sbPaymentBase;
    }

    public void setSbPaymentBase(BigDecimal sbPaymentBase) {
        this.sbPaymentBase = sbPaymentBase;
    }

    public BigDecimal getGjjPaymentBase() {
        return gjjPaymentBase;
    }

    public void setGjjPaymentBase(BigDecimal gjjPaymentBase) {
        this.gjjPaymentBase = gjjPaymentBase;
    }

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public Date getMonth() {
        return month;
    }

    public void setMonth(Date month) {
        this.month = month;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }
    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }
    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }
    public BigDecimal getYingfa() {
        return yingfa;
    }

    public void setYingfa(BigDecimal yingfa) {
        this.yingfa = yingfa;
    }
    public BigDecimal getDabingyibao() {
        return dabingyibao;
    }

    public void setDabingyibao(BigDecimal dabingyibao) {
        this.dabingyibao = dabingyibao;
    }
    public BigDecimal getGerenyanglao() {
        return gerenyanglao;
    }

    public void setGerenyanglao(BigDecimal gerenyanglao) {
        this.gerenyanglao = gerenyanglao;
    }
    public BigDecimal getGerenyibao() {
        return gerenyibao;
    }

    public void setGerenyibao(BigDecimal gerenyibao) {
        this.gerenyibao = gerenyibao;
    }
    public BigDecimal getGerenshiye() {
        return gerenshiye;
    }

    public void setGerenshiye(BigDecimal gerenshiye) {
        this.gerenshiye = gerenshiye;
    }
    public BigDecimal getGerengongjijin() {
        return gerengongjijin;
    }

    public void setGerengongjijin(BigDecimal gerengongjijin) {
        this.gerengongjijin = gerengongjijin;
    }
    public BigDecimal getGsyanglao() {
        return gsyanglao;
    }

    public void setGsyanglao(BigDecimal gsyanglao) {
        this.gsyanglao = gsyanglao;
    }
    public BigDecimal getGsyibao() {
        return gsyibao;
    }

    public void setGsyibao(BigDecimal gsyibao) {
        this.gsyibao = gsyibao;
    }
    public BigDecimal getGsshiye() {
        return gsshiye;
    }

    public void setGsshiye(BigDecimal gsshiye) {
        this.gsshiye = gsshiye;
    }
    public BigDecimal getGsshengyu() {
        return gsshengyu;
    }

    public void setGsshengyu(BigDecimal gsshengyu) {
        this.gsshengyu = gsshengyu;
    }
    public BigDecimal getGsgongshang() {
        return gsgongshang;
    }

    public void setGsgongshang(BigDecimal gsgongshang) {
        this.gsgongshang = gsgongshang;
    }
    public BigDecimal getGsgongjijin() {
        return gsgongjijin;
    }

    public void setGsgongjijin(BigDecimal gsgongjijin) {
        this.gsgongjijin = gsgongjijin;
    }
    public BigDecimal getGeshui() {
        return geshui;
    }

    public void setGeshui(BigDecimal geshui) {
        this.geshui = geshui;
    }
    public BigDecimal getYingfamianshui() {
        return yingfamianshui;
    }

    public void setYingfamianshui(BigDecimal yingfamianshui) {
        this.yingfamianshui = yingfamianshui;
    }
    public BigDecimal getYingfamianshuicw() {
        return yingfamianshuicw;
    }

    public void setYingfamianshuicw(BigDecimal yingfamianshuicw) {
        this.yingfamianshuicw = yingfamianshuicw;
    }
    public BigDecimal getActual() {
        return actual;
    }

    public void setActual(BigDecimal actual) {
        this.actual = actual;
    }
    public BigDecimal getAlreadyMny() {
        return alreadyMny;
    }

    public void setAlreadyMny(BigDecimal alreadyMny) {
        this.alreadyMny = alreadyMny;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankAddress() {
        return bankAddress;
    }

    public void setBankAddress(String bankAddress) {
        this.bankAddress = bankAddress;
    }
    public String getAcSetCode() {
        return acSetCode;
    }

    public void setAcSetCode(String acSetCode) {
        this.acSetCode = acSetCode;
    }
    public String getAcSet() {
        return acSet;
    }

    public void setAcSet(String acSet) {
        this.acSet = acSet;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    
}
